/**
 * 
 */
package de.mpiwg.itgroup.annotations.restlet.annotations_ui;

import java.util.List;

import org.restlet.data.Form;
import org.restlet.data.MediaType;
import org.restlet.data.Reference;
import org.restlet.data.Status;
import org.restlet.representation.Representation;
import org.restlet.representation.StringRepresentation;
import org.restlet.resource.Get;
import org.restlet.resource.Post;

import de.mpiwg.itgroup.annotations.Actor;
import de.mpiwg.itgroup.annotations.Person;
import de.mpiwg.itgroup.annotations.neo4j.AnnotationStore.NodeTypes;

/**
 * Resource class for the members of an annotation group.
 * 
 * @author casties
 * 
 */
public class GroupMembersResource extends GroupResource {

    /**
     * GET with HTML content type. Shows the members of the group.
     * 
     * @param entity
     * @return
     */
    @Get("html")
    public Representation doGetHTML(Representation entity) {
        // id from URI /annotations/groups/{id}/members
        if (requestId == null || requestId.isEmpty()) {
            // invalid id
            setStatus(Status.CLIENT_ERROR_BAD_REQUEST);
            return null;
        }
        String result = null;
        Reference thisUrl = this.getReference();
        Reference groupsUrl = thisUrl.getParentRef();
        result = "<html><body>\n<h1>Group members</h1>\n";
        result += String.format("<p>Group: %s <a href=\"%s\">(%s)</a></p>\n", group.getName(), groupsUrl, group.getId());
        result += "<p>Members:</p>\n";
        result += "<table>";
        List<Person> members = store.getMembersOfGroup(group);
        for (Person p : members) {
            result += String.format("<tr><td>%s</td><td>(%s)</td>", p.getName(), p.getIdString());
            //result += String.format("<td></td></tr>\n", p.getName(), p.getIdString());
        }
        result += "</table>\n";
        result += String.format("<form method=\"post\" action=\"%s\">\n", thisUrl);
        result += "<p>Add new member: <select name=\"add_member\">\n";
        for (Actor p : store.getActors("uri", "*", NodeTypes.PERSON)) {
            result += String.format("<option value=\"%s\">%s</option>\n", p.getIdString(), p.getName());
        }
        result += "</select>\n";
        result += "<input type=\"submit\"/>\n";
        result += "</form>\n";
        result += "</body>\n</html>";

        return new StringRepresentation(result, MediaType.TEXT_HTML);
    }

    /**
     * POST adds or deletes members of the Group.
     * 
     * @return
     */
    @Post
    public Representation doPost(Representation entity) {
        logger.debug("GroupMembersResource doPost!");
        // TODO: do authentication
        Form form = new Form(entity);
        String addMemberId = form.getFirstValue("add_member");
        String delMemberId = form.getFirstValue("del_member");
        if (group == null || ((addMemberId == null || addMemberId.isEmpty()) 
                && (delMemberId == null || delMemberId.isEmpty()))) {
            // no id
            setStatus(Status.CLIENT_ERROR_BAD_REQUEST);
            return null;
        }
        
        // return 303: see other
        setStatus(Status.REDIRECTION_SEE_OTHER);
        // go get same URL
        Reference thisUrl = this.getReference();
        this.getResponse().setLocationRef(thisUrl);
        return null;
    }

}
